@@ -4,7 +4,7 @@ use Moo;
 use utf8;
 use feature qw( say );
 
-our $VERSION = '0.000038';
+our $VERSION = '0.000039';
 
 use App::perlimports           ();
 use App::perlimports::Config   ();
@@ -14,7 +14,6 @@ use Getopt::Long::Descriptive qw( describe_options );
 use Log::Dispatch ();
 use Path::Tiny qw( path );
 use Try::Tiny qw( catch try );
-use Types::Path::Tiny qw( Path );
 use Types::Standard qw( ArrayRef Bool HashRef InstanceOf Object Str );
 
 has _args => (
@@ -33,9 +32,8 @@ has _config => (
 
 has _config_file => (
     is       => 'ro',
-    isa      => Path,
+    isa      => Str,
     init_arg => 'config',
-    coerce   => Path->coercion,
     builder  => '_build_config_file',
 );
 
@@ -406,7 +404,7 @@ App::perlimports::CLI - CLI arg parsing for C<perlimports>
 
 =head1 VERSION
 
-version 0.000038
+version 0.000039
 
 =head1 DESCRIPTION
 
